@@ -20,11 +20,7 @@
 #include <KSharedConfig>
 #include <KStandardGuiItem>
 
-#ifdef HAVE_PIMTEXTEDIT
-#include <TextCustomEditor/RichTextEditor>
-#else
 #include <QTextEdit>
-#endif
 
 #include <QDebug>
 #include <QDialogButtonBox>
@@ -42,22 +38,17 @@ using namespace Kleo;
 AuditLogViewer::AuditLogViewer(const QString &log, QWidget *parent)
     : QDialog(parent)
     , m_log(/* sic */)
-    ,
-#ifdef HAVE_PIMTEXTEDIT
-    m_textEdit(new TextCustomEditor::RichTextEditorWidget(this))
-#else
-    m_textEdit(new QTextEdit(this))
-#endif
+    , m_textEdit(new QTextEdit(this))
 {
     setWindowTitle(i18nc("@title:window", "View GnuPG Audit Log"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox{};
 
-    auto copyClipBtn = buttonBox->addButton(i18n("&Copy to Clipboard"), QDialogButtonBox::ActionRole);
+    auto copyClipBtn = buttonBox->addButton(i18nc("@action:button", "&Copy to Clipboard"), QDialogButtonBox::ActionRole);
     copyClipBtn->setObjectName(QLatin1StringView("copyClipBtn"));
     copyClipBtn->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     connect(copyClipBtn, &QPushButton::clicked, this, &AuditLogViewer::slotCopyClip);
 
-    auto saveAsBtn = buttonBox->addButton(i18n("&Save to Disk..."), QDialogButtonBox::ActionRole);
+    auto saveAsBtn = buttonBox->addButton(i18nc("@action:button", "&Save to Disk..."), QDialogButtonBox::ActionRole);
     saveAsBtn->setObjectName(QLatin1StringView("saveAsBtn"));
     saveAsBtn->setIcon(QIcon::fromTheme(QStringLiteral("document-save-as")));
     connect(saveAsBtn, &QPushButton::clicked, this, &AuditLogViewer::slotSaveAs);
@@ -115,7 +106,7 @@ void AuditLogViewer::showAuditLog(QWidget *parent, const AuditLogEntry &auditLog
 
     const auto alv = new AuditLogViewer{auditLog.text(), parent};
     alv->setAttribute(Qt::WA_DeleteOnClose);
-    alv->setWindowTitle(title.isEmpty() ? i18n("GnuPG Audit Log Viewer") : title);
+    alv->setWindowTitle(title.isEmpty() ? i18nc("@title:window", "GnuPG Audit Log Viewer") : title);
     alv->show();
 }
 
