@@ -114,6 +114,8 @@ QStringList Kleo::gnupgFileWhitelist()
         QStringLiteral("secring.gpg"),
         // Secret keys (living under private-keys-v1.d/)
         QStringLiteral("*.key"),
+        // the keyboxd database
+        QStringLiteral("pubring.db"),
         // Changes to the trustmodel / compliance mode might
         // affect validity so we check this, too.
         // Globbing for gpg.conf* here will trigger too often
@@ -132,6 +134,8 @@ QStringList Kleo::gnupgFolderWhitelist()
     return {
         gnupgHome.path(),
         gnupgPrivateKeysDirectory(),
+        // for the keyboxd database
+        gnupgHome.filePath(QStringLiteral("public-keys.d")),
     };
 }
 
@@ -215,7 +219,7 @@ QString Kleo::gpgConfListDir(const char *which)
 
 static std::array<int, 3> getVersionFromString(const char *actual, bool &ok)
 {
-    std::array<int, 3> ret;
+    std::array<int, 3> ret{-1, -1, -1};
     ok = false;
 
     if (!actual) {
@@ -225,7 +229,7 @@ static std::array<int, 3> getVersionFromString(const char *actual, bool &ok)
     QString versionString = QString::fromLatin1(actual);
 
     // Try to fix it up
-    QRegularExpression rx(QRegularExpression::anchoredPattern(QLatin1String(R"((\d+)\.(\d+)\.(\d+)(?:-svn\d+)?.*)")));
+    QRegularExpression rx(QRegularExpression::anchoredPattern(QLatin1StringView(R"((\d+)\.(\d+)\.(\d+)(?:-svn\d+)?.*)")));
     QRegularExpressionMatch match;
     for (int i = 0; i < 3; i++) {
         match = rx.match(versionString);
@@ -311,6 +315,10 @@ const QString &Kleo::paperKeyInstallPath()
 
 bool Kleo::haveKeyserverConfigured()
 {
+    if (engineIsVersion(2, 4, 4) //
+        || (engineIsVersion(2, 2, 42) && !engineIsVersion(2, 3, 0))) {
+        return Kleo::keyserver() != QLatin1StringView{"none"};
+    }
     if (engineIsVersion(2, 1, 19)) {
         // since 2.1.19 there is a builtin keyserver
         return true;
@@ -324,6 +332,10 @@ QString Kleo::keyserver()
     if (result.isEmpty()) {
         result = getCryptoConfigStringValue("dirmngr", "keyserver");
     }
+    if (result.endsWith(QLatin1StringView{"://none"})) {
+        // map hkps://none, etc., to "none"; see https://dev.gnupg.org/T6708
+        result = QStringLiteral("none");
+    }
     return result;
 }
 
@@ -452,7 +464,7 @@ QStringList Kleo::backendVersionInfo()
             qCDebug(LIBKLEO_LOG) << "gpgconf stdout:" << p.readAllStandardOutput();
         } else {
             const QByteArray output = p.readAllStandardOutput().replace("\r\n", "\n");
-            qCDebug(LIBKLEO_LOG) << "gpgconf stdout:" << p.readAllStandardOutput();
+            qCDebug(LIBKLEO_LOG) << "gpgconf stdout:" << output;
             const auto lines = output.split('\n');
             for (const auto &line : lines) {
                 if (line.startsWith("* GnuPG") || line.startsWith("* Libgcrypt")) {
@@ -491,46 +503,35 @@ auto startGpgConf(const QStringList &arguments, Function1 onSuccess, Function2 o
     QObject::connect(process, &QProcess::readyReadStandardOutput, [process]() {
         (void)process->readAllStandardOutput(); /* ignore stdout */
     });
-    QObject::connect(process,
-                     qOverload<int, QProcess::ExitStatus>(&QProcess::finished),
-                     [process, onSuccess, onFailure](int exitCode, QProcess::ExitStatus exitStatus) {
-                         if (exitStatus == QProcess::NormalExit) {
-                             qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") exited (exit code: " << exitCode << ")";
-                             if (exitCode == 0) {
-                                 onSuccess();
-                             } else {
-                                 onFailure();
-                             }
-                         } else {
-                             qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") crashed (exit code: " << exitCode << ")";
-                             onFailure();
-                         }
-                         process->deleteLater();
-                     });
+    QObject::connect(process, &QProcess::finished, [process, onSuccess, onFailure](int exitCode, QProcess::ExitStatus exitStatus) {
+        if (exitStatus == QProcess::NormalExit) {
+            qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") exited (exit code: " << exitCode << ")";
+            if (exitCode == 0) {
+                onSuccess();
+            } else {
+                onFailure();
+            }
+        } else {
+            qCDebug(LIBKLEO_LOG).nospace() << "gpgconf (" << process << ") crashed (exit code: " << exitCode << ")";
+            onFailure();
+        }
+        process->deleteLater();
+    });
 
     qCDebug(LIBKLEO_LOG).nospace() << "Starting gpgconf (" << process << ") with arguments " << process->arguments().join(QLatin1Char(' ')) << " ...";
     process->start();
 
     return process;
 }
-
-static auto startGpgConf(const QStringList &arguments)
-{
-    return startGpgConf(
-        arguments,
-        []() {},
-        []() {});
 }
 
-}
-
-void Kleo::launchGpgAgent()
+void Kleo::launchGpgAgent(Kleo::LaunchGpgAgentOptions options)
 {
-    static QPointer<QProcess> process;
-    static qint64 mSecsSinceEpochOfLastLaunch = 0;
-    static int numberOfFailedLaunches = 0;
+    static thread_local QPointer<QProcess> process;
+    static thread_local qint64 mSecsSinceEpochOfLastLaunch = 0;
+    static thread_local int numberOfFailedLaunches = 0;
 
-    if (Kleo::Assuan::agentIsRunning()) {
+    if ((options == CheckForRunningAgent) && Kleo::Assuan::agentIsRunning()) {
         qCDebug(LIBKLEO_LOG) << __func__ << ": gpg-agent is already running";
         return;
     }
@@ -559,16 +560,19 @@ void Kleo::launchGpgAgent()
         });
 }
 
-void Kleo::killDaemons()
+void Kleo::restartGpgAgent()
 {
     static QPointer<QProcess> process;
 
     if (process) {
-        qCDebug(LIBKLEO_LOG) << __func__ << ": The daemons are already being shut down";
+        qCDebug(LIBKLEO_LOG) << __func__ << ": gpg-agent is already being restarted";
         return;
     }
 
-    process = startGpgConf({QStringLiteral("--kill"), QStringLiteral("all")});
+    auto startAgent = []() {
+        Kleo::launchGpgAgent(SkipCheckForRunningAgent);
+    };
+    process = startGpgConf({QStringLiteral("--kill"), QStringLiteral("all")}, startAgent, startAgent);
 }
 
 const std::vector<std::string> &Kleo::availableAlgorithms()
@@ -659,3 +663,24 @@ bool Kleo::gpgvVerify(const QString &filePath, const QString &sigPath, const QSt
     }
     return ret;
 }
+
+std::vector<QByteArray> Kleo::readSecretKeyFile(const QString &keyGrip)
+{
+    const auto filename = QStringLiteral("%1.key").arg(keyGrip);
+    const auto path = QDir{Kleo::gnupgPrivateKeysDirectory()}.filePath(filename);
+
+    QFile file{path};
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        qCDebug(LIBKLEO_LOG) << "Cannot open the private key file" << path << "for reading";
+        return {};
+    }
+
+    std::vector<QByteArray> lines;
+    while (!file.atEnd()) {
+        lines.push_back(file.readLine());
+    }
+    if (lines.empty()) {
+        qCDebug(LIBKLEO_LOG) << "The private key file" << path << "is empty";
+    }
+    return lines;
+}
